/* 
 *  myauth_config.h
 *
 *  Copyright (C) Svein Olav Bjerkeset, 2012
 *  License: GNU GENERAL PUBLIC LICENSE Version 3
 */

#ifndef MYAUTH_CONFIG_H
#define MYAUTH_CONFIG_H

#include <httpd.h>
#include <http_config.h>
#include <apr_strings.h>

#define MYAUTH_ENC_PLAIN  1
#define MYAUTH_ENC_CRYPT  2
#define MYAUTH_ENC_MYSQL  4    /* default */

#ifdef USE_OPENSSL
#include <openssl/bio.h>
#include <openssl/evp.h>
#define MYAUTH_ENC_MD5BASE64 8
#else
#define MYAUTH_ENC_MD5BASE64 0
#endif

#ifndef AUTHN_PROVIDER_VERSION
#define AUTHN_PROVIDER_VERSION "0"
#endif

#ifndef AP_AUTH_INTERNAL_PER_CONF
#define AP_AUTH_INTERNAL_PER_CONF 1
#endif

#ifndef AUTHZ_PROVIDER_VERSION
#define AUTHZ_PROVIDER_VERSION "0"
#endif

#ifndef AUTHZ_PROVIDER_GROUP
#define AUTHZ_PROVIDER_GROUP "authz"
#endif

#ifndef HAVE_ENUM_AUTHZ_STATUS
typedef enum {
	AUTHZ_DENIED,
	AUTHZ_GRANTED,
	AUTHZ_NEUTRAL,
	AUTHZ_GENERAL_ERROR,
	AUTHZ_DENIED_NO_USER      /* denied because r->user == NULL */
} authz_status;
#endif

struct myauth_config_struct {
	char*		my_host;
	uint16_t	my_port;
	char*		my_db;
	char*		my_login;
	char*		my_passw;
	int			my_authoritative;
	char*		my_usertbl;
	char*		my_userfld;
	char*		my_pwfld;
	unsigned	my_enctype;
	char*		my_grpfld;
	char*		my_grptbl;
};
typedef struct myauth_config_struct myauth_config_rec;

const char* myauth_set_slot (cmd_parms *parms, void *mconfig, const char *arg);
const char* myauth_set_port (cmd_parms *parms, void *mconfig, const char *arg);
const char* myauth_set_enctype (cmd_parms *parms, void *mconfig,
	const char *word1, const char *word2);

#endif /* MYAUTH_CONFIG_H */
